### example.code.R
### 10/6/18 cmm

# Reading in data from a text file using the read.table function.
# Note I’m reading this as a local file in the same directory as my R project.
# A full path name will also work, but you need to use front slashes (as in Unix) not back slashes (as in Windows).  R can also read web address path names.

help(read.table)
example.data <- read.table("example.dat", header = TRUE)

# Note that the variable names, “x1”, “x2”, and “y”, 
# were in the first line of the data file (hence “header=TRUE” above).

# head() and tail() show the first and last six cases
head(example.data)
# x1        x2         y
# 1 20.42405 0.3015210 36.172660
# 2 32.74049 1.3469176 28.415784
# 3 24.94999 1.1793272 28.376674
# 4 27.72610 0.9360980 - 4.515564
# 5 13.54863 2.0794730 12.169991
# 6 20.98872 0.9834769 27.996572
tail(example.data)
# x1        x2         y
# 95  15.55136 0.1174105 13.759553
# 96  24.08216 1.4166113 16.811138
# 97  21.98282 1.3674975 25.881897
# 98  11.77869 1.4063972 28.399718
# 99  10.40391 1.8212314  4.083947
# 100 22.86390 1.2976605 23.642835

# The following shows the first 10 cases in the data file.  “[1:10, ]” means rows 1 through 10 and all of the columns.  “[4, 3]” would refer to the value in the 4th row, 3rd column.  “[, 1:2]” all of the rows and the first two columns (x1 and x2).
example.data[1:10, ]
# x1        x2         y
# 1  20.42405 0.3015210 36.172660
# 2  32.74049 1.3469176 28.415784
# 3  24.94999 1.1793272 28.376674
# 4  27.72610 0.9360980 - 4.515564
# 5  13.54863 2.0794730 12.169991
# 6  20.98872 0.9834769 27.996572
# 7  15.17568 0.9979689 23.448322
# 8  32.34730 1.0945375 23.722077
# 9  24.18020 0.2266746 17.164225
# 10 17.83226 0.6170786 18.524674

# Dataframes
dim(example.data)
# [1] 100   3
nrow(example.data)
# [1] 100
ncol(example.data)
# [1] 3

is.array(example.data)
# [1] FALSE
is.data.frame(example.data)
# [1] TRUE

# Indexing individual values
example.data[1, 1]
# [1] 20.42405
example.data[8, 3]
# [1] 23.72208
example.data$x1[1]
# [1] 20.42405
example.data$y[3]
# [1] 28.37667

# Vector components of data frames
is.vector(example.data$x1)
# [1] TRUE
length(example.data$x1)
# [1] 100
mean(example.data$x1)
# [1] 19.86305
mean(example.data[, 1])
# [1] 19.86305
sum(example.data[2, ])
# [1] 62.5032
min(example.data$y)
# [1] - 4.515564
max(example.data$y)
# [1] 47.21957

# Always best to look at the data before analyzing it

# Histogram

# hist(example.data$x1)


# hist(example.data$y)

# Plot function:minimal parameters – the first is the x -
#   axis variable, the second is the y - axis variable.  A graphics window is automatically opened.
plot(example.data$x1, example.data$y)


# Using lm() to fit a linear regression model to the data.  Open the description of lm using help.  Note that lm expects the first parameter to be a formula.  In this example, the formula is y ~
#   x1 + x2.  This indicates that y is the dependent variable and x1 and x2 are the independent variables (covariates).  By default an intercept term is used.  To explicitly ask for an intercept term use y ~
#   1 + x1 + x2.  To eliminate the intercept term use y ~ -1 + x1 + x2.

lm.results <-
  lm(y ~ x1 + x2, data = example.data)

# Note that “lm.results” is the name of the object that stores all the information from the lm function.
lm.results
# 
# Call:lm(formula = y ~ x1 + x2, data = example.data)
# 
# Coefficients:(Intercept)           x1           x2
# 5.9103       0.6385       0.8105
# 
# The “summary” function gives more detail.
summary(lm.results)

# Call:lm(formula = y ~ x1 + x2, data = example.data)
# 
# Residuals:Min       1Q   Median       3Q      Max
# - 28.8878  - 7.0357  - 0.7815   7.2315  27.4582
# 
# Coefficients:Estimate Std. Error t value Pr( |
#                                                t | )
# (Intercept)   5.9103     4.1817   1.413 0.160753
# x1            0.6385     0.1874   3.407 0.000958 **
#   *
#   x2            0.8105     2.1384   0.379 0.705508---Signif. codes:0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error:10.65 on 97 degrees of freedom
# Multiple R - Squared:0.1139,     Adjusted R -
#   squared:0.09566
# F - statistic:6.236 on 2 and 97 DF,  p - value:0.002833

# To get the sums of squares use the aov() function
aov(lm.results)
# Call:aov(formula = lm.results)
# 
# Terms:x1        x2 Residuals
# Sum of Squares   1399.235    16.304 11009.424
# Deg. of Freedom         1         1        97
# 
# Residual standard error:10.6536
# Estimated effects may be unbalanced

# summary(aov(lm.results))
# Df  Sum Sq Mean Sq F value    Pr(F)
# x1           1  1399.2  1399.2 12.3281 0.0006788 **
#   *
#   x2           1    16.3    16.3  0.1436 0.7055075
# Residuals   97 11009.4   113.5---Signif. codes:0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Prediction from the regression equation using the predict function
y.hat <- predict(lm.results)
head(y.hat)
# 1        2        3        4        5        6
# 19.19549 27.90687 22.79677 24.37220 16.24647 20.10875
tail(y.hat)
# 95       96       97       98       99      100
# 15.93504 22.43497 21.05472 14.57085 14.02926 21.56069



