### test.analysis.R
### Cori Mar
### October 2018

### Reading in the data set
dd <- read.csv(file = "test.csv", header = T)

### Structure of the data set
# > str(dd)
# 'data.frame':	200 obs. of  5 variables:
#   $ age : int  30 35 45 61 27 61 63 49 48 20 ...
# $ sex : int  0 0 0 0 0 0 0 0 0 0 ...
# $ race: int  0 1 0 0 2 2 0 1 0 0 ...
# $ LE  : int  19 29 28 24 27 33 NA 39 21 28 ...
# $ dep : int  16 15 24 21 29 25 10 21 29 31 ...

### making race and sex factors and labeling their values
dd$race  <- factor(dd$race,
                  levels = c(0,1,2),
                  labels = c("white", "black", "other"))

dd$sex <- factor(dd$sex,
                 levels=c(0,1),
                 labels=c("male","female"))

### this causes everything that would ordinary go to the console
### to be printed in an ascii text file
sink(file="test.output.txt",append=TRUE)

cat("Analysis of data file test.csv")

cat("\n\nRace Frequencies\n")
table(dd$race, exclude=NULL)
cat("\n\nSex Frequencies\n")
table(dd$sex, exclude=NULL)
cat("\n\nSex by Race Frequencies\n")
table(dd$sex, dd$race, exclude = NULL)

cat("\n\nMultiple linear regression predicting depression\n")
dep.fit <- lm(dep ~ age + sex + race + LE, data = dd)
summary(dep.fit)

### this resets the output to stdout (console)
sink(file=NULL)

####################################

### Selecting cases where age <= 35
newdat <- subset(dd, age <= 35)
# > str(newdat)
# 'data.frame':	65 obs. of  5 variables:
# $ age : int  30 35 27 20 27 26 28 24 30 18 ...
# $ sex : Factor w/ 2 levels "male","female": 1 1 1 1 1 1 1 1 1 1 ...
# $ race: Factor w/ 3 levels "white","black",..: 1 2 3 1 1 1 1 1 1 1 ...
# $ LE  : int  19 29 27 28 19 17 18 14 21 27 ...
# $ dep : int  16 15 29 31 19 14 15 22 20 27 ...

### save the new data frame
save(newdat, file="test.ageLE.35.RData")

### save the new data frame as a .csv file
write.csv(newdat, file="test.ageLE.35.csv",
          quote=FALSE, row.names=FALSE)

### Selecting variables age, race, and dep
newdat2 <- subset(dd, select = c(age, race, dep))
# > str(newdat2)
# 'data.frame':	200 obs. of  3 variables:
# $ age : int  30 35 45 61 27 61 63 49 48 20 ...
# $ race: Factor w/ 3 levels "white","black",..: 1 2 1 1 3 3 1 2 1 1 ...
# $ dep : int  16 15 24 21 29 25 10 21 29 31 ...

### EXERCISE: write newdat2 to a tab delimited .txt file

### Add ID variable to dataframe
dd$ID <- 1001:1200
# > str(dd)
# 'data.frame':	200 obs. of  6 variables:
#   $ age : int  30 35 45 61 27 61 63 49 48 20 ...
# $ sex : Factor w/ 2 levels "male","female": 1 1 1 1 1 1 1 1 1 1 ...
# $ race: Factor w/ 3 levels "white","black",..: 1 2 1 1 3 3 1 2 1 1 ...
# $ LE  : int  19 29 28 24 27 33 NA 39 21 28 ...
# $ dep : int  16 15 24 21 29 25 10 21 29 31 ...
# $ ID  : int  1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 ...

### saving the new data frame
save(dd, file="test.plus.ID.RData")
